#
# spec file for package encfs
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           encfs
BuildRequires:  boost-devel
BuildRequires:  fuse-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  rlog-devel
BuildRequires:  zlib-devel
Requires:       fuse
Summary:        Userspace Encrypted File System
License:        GPL-2.0+ and GPL-3.0+
Group:          System/Filesystems
Version:        1.8
Release:        3.3
Source:         https://github.com/vgough/encfs/archive/v%{version}.tar.gz
Patch:          configure-fix.patch
Url:            https://vgough.github.io/encfs/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
EncFS provides an encrypted file system, layered on top of a normal
directory tree and encrypts individual files which are stored in the
hosting directory tree.

This has several advantages over the loopback encryption which
provided by the Linux kernel: 
- No space is and has to be reserved, encrypted files only 
  take the space that they really occupy
- Backups: encrypted files can be individually backed-up on the host
  filesystem
- Layering: Since it's hosted on a normal filesystem, encfs can be
  used on filesystems which normally have no support encryption,
  like NFS or other userspace filesystems.

EncFS is implemented as a userspace filesystem in an unprivileged
application using fuse (FUSE (Filesystem in USErspace)).

%prep
%setup
%patch -p1

%build
autoreconf -fiv

%configure --with-boost-libdir=%{_libdir}
%{__make} %{?_smp_flags}

%install
make DESTDIR="$RPM_BUILD_ROOT" install
rm -f $RPM_BUILD_ROOT%{_libdir}/*.{la,so}

%post
%{run_ldconfig}

%postun
%{run_ldconfig}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING* ChangeLog DESIGN.md PERFORMANCE.md README* TRANSLATORS
%{_mandir}/man?/*
%{_bindir}/encfs*
%{_libdir}/libencfs.so.*

%changelog
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 1.8
  * No short chanlog available; please read the ChangeLog file into
    /usr/share/doc/packages/encfs/ChangeLog
- Update Url to new project home
- Use download Url as source
- Copy DESIGN.md, PERFORMANCE.mde and TRANSLATORS into doc directory
- Remove obsolete patchs
  * encfs-1.7.4-fixReverseAbsoluteSymlinks.diff
  * encfs-1.7.4-fix-bashisms.patch
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashism in encfssh script
- add patches:
  * encfs-1.7.4-fix-bashisms.patch
* Tue Apr  1 2014 wagner-thomas@gmx.at
- applied patchencfs-1.7.4-fixReverseAbsoluteSymlinks.diff from
  https://code.google.com/p/encfs/issues/detail?id=29
  This fixes encoding of symlinks starting with a "/"
- Added patches:
  * encfs-1.7.4-fixReverseAbsoluteSymlinks.diff
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Tue Aug 30 2011 crrodriguez@opensuse.org
- Fix build, axing all m4 macros was a bad idea...
* Fri Dec  3 2010 mszeredi@suse.cz
- updated to version 1.7.4
  * fixes bug with --reverse option setting which causes files to
    be stored incorrectly
* Mon Sep  6 2010 mszeredi@suse.cz
- updated to version 1.7.2
  * allow per-block random bytes to be configured independently of
    per-block MAC.
  * new IV initialization
  * fix component configuration to ease adding flags or config
* Mon Jun 28 2010 mszeredi@suse.cz
- updated to version 1.6.0
  * build fixes
  * add support for version field within serialized config
  * add options to help automate filesystem creation
  * modification and access times can be changed for symlinks
  * try to maintain modtime during rename
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Wed Jun  3 2009 mszeredi@suse.cz
- fix compile error due to missing "const" qualifier
* Wed Oct 29 2008 mszeredi@suse.de
- updated to version 1.5.0
  * fix bug in export - wasn't able to export symlinks (launchpad bug
    [#201974])
  * add makeKey program and showKey option to encfsctl
  * remove logs in Context, which displayed plaintext names
  * use PBKDF2 for key generation with salt and variable iteration
    count
  * allow for automatic upgrade to PBKDF2 when changing passwords
  * enable file hole support by default
* Tue Apr 15 2008 mszeredi@suse.de
- updated to version 1.4.2
  * move buffer management to avoid memory leak in case of decoding
    error
  * reverse encryption support
  * fix rename bug by tracking and applying undo in all error paths
    (launchpad bug #160214)
  * add '-o' option which passes arg through to fuse
  * add -h option
  * add mount-on-demand
  * change license file to GPL3
  * enlarge max password length
  * run extpass command via shell, to allow passing arguments
    to program
  * fix directory rename issue (launchpad bug #183358)
  * no arg required for stdinpass
  * ensure paths end in '/'. fixes (launchpad bug #184905)
  * add zero-block pass-through option, enabling allow-holes code
  * fix bug in export - wasn't able to export symlinks (launchpad
    bug #201974)
  * switch to V6 XML config format
* Wed Oct 24 2007 mszeredi@suse.de
- Fix compile errors and warnings in beta
* Fri Aug 10 2007 bk@suse.de
- Add "Requires: fuse" to ensure that fuse is present (285101#c29)
- Use %%find_lang to mark locale files with missing %%lang (rpmlint)
* Thu Mar 29 2007 meissner@suse.de
- buildrequires zlib-devel
* Thu Feb 15 2007 mszeredi@suse.cz
- updated to version 1.3.2
  * fix failure to process HMAC correctly in case of read error
  * builds with GCC 4.2
  * add workaround for group permission problem in 'public' mode
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.3.1.
  * ports for fuse-2.5
  * bugfixes for null filename encryption
  * fix directory rename error
  * new translations
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 tiwai@suse.de
- fix the build with fuse 2.5.0.
* Tue Nov 15 2005 tiwai@suse.de
- updated to version 1.2.5.
* Fri Sep 30 2005 tiwai@suse.de
- updated to version 1.2.4.
* Wed May 25 2005 tiwai@suse.de
- initial version: 1.2.2
